#!/bin/sh
set -ev

test $DARCS || DARCS=$PWD/../darcs

rm -rf temp1 temp2
mkdir temp1 temp2
cd temp1
$DARCS init
touch foo bar
$DARCS add foo bar
$DARCS record -a -m add_foo_bar -A x
$DARCS mv foo zig
$DARCS mv bar foo
$DARCS mv zig bar
$DARCS record -a -m swap_foo_bar -A x
cd ../temp2
$DARCS init
$DARCS pull -v -a ../temp1
cd ..
rm -rf temp1 temp2

